==> jc-1.4.0.tar.gz: soot/tagkit/IntegerConstantValueTag.h <==
// public class soot.tagkit.IntegerConstantValueTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class de174c96e42d5040 soot_tagkit_IntegerConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_IntegerConstantValueTag_H_
#define _JC_soot_tagkit_IntegerConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$sub_refs	_jc_soot_tagkit_IntegerConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs	_jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$refs	_jc_soot_tagkit_IntegerConstantValueTag$refs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$nonrefs	_jc_soot_tagkit_IntegerConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$object	_jc_soot_tagkit_IntegerConstantValueTag$object;

typedef const struct _jc_soot_tagkit_IntegerConstantValueTag$vmethods	_jc_soot_tagkit_IntegerConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_IntegerConstantValueTag$vtable	_jc_soot_tagkit_IntegerConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_IntegerConstantValueTag$vtype	_jc_soot_tagkit_IntegerConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_IntegerConstantValueTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_IntegerConstantValueTag$object *, jint);

// Virtual methods
extern jint _jc_soot_tagkit_IntegerConstantValueTag$method$getIntValue$d4de86d90a7b63ff(_jc_env *, struct _jc_soot_tagkit_IntegerConstantValueTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_IntegerConstantValueTag$method_info$getIntValue$d4de86d90a7b63ff;

// Virtual methods structure
struct _jc_soot_tagkit_IntegerConstantValueTag$vmethods {
	jint	(*getIntValue$d4de86d90a7b63ff)(_jc_env *, struct _jc_soot_tagkit_IntegerConstantValueTag$object *);
};

// Vtable
struct _jc_soot_tagkit_IntegerConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_IntegerConstantValueTag$vmethods	soot_tagkit_IntegerConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_IntegerConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_IntegerConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_IntegerConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_IntegerConstantValueTag$refs {
    _jc_soot_tagkit_IntegerConstantValueTag$sub_refs	soot_tagkit_IntegerConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_IntegerConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs	soot_tagkit_IntegerConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_IntegerConstantValueTag$object {
	_jc_soot_tagkit_IntegerConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_IntegerConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_IntegerConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_IntegerConstantValueTag$vtype _jc_soot_tagkit_IntegerConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_IntegerConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_IntegerConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_IntegerConstantValueTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/IntegerConstantValueTag.h <==
// public class soot.tagkit.IntegerConstantValueTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class de174c96e42d5040 soot_tagkit_IntegerConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_IntegerConstantValueTag_H_
#define _JC_soot_tagkit_IntegerConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$sub_refs	_jc_soot_tagkit_IntegerConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs	_jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$refs	_jc_soot_tagkit_IntegerConstantValueTag$refs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$nonrefs	_jc_soot_tagkit_IntegerConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_IntegerConstantValueTag$object	_jc_soot_tagkit_IntegerConstantValueTag$object;

typedef const struct _jc_soot_tagkit_IntegerConstantValueTag$vmethods	_jc_soot_tagkit_IntegerConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_IntegerConstantValueTag$vtable	_jc_soot_tagkit_IntegerConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_IntegerConstantValueTag$vtype	_jc_soot_tagkit_IntegerConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_IntegerConstantValueTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_IntegerConstantValueTag$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_IntegerConstantValueTag$method$getIntValue$d4de86d90a7b63ff(_jc_env *, struct _jc_soot_tagkit_IntegerConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_IntegerConstantValueTag$method_info$getIntValue$d4de86d90a7b63ff;

// Virtual methods structure
struct _jc_soot_tagkit_IntegerConstantValueTag$vmethods {
	jint	(*getIntValue$d4de86d90a7b63ff)(_jc_env *, struct _jc_soot_tagkit_IntegerConstantValueTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_IntegerConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_IntegerConstantValueTag$vmethods	soot_tagkit_IntegerConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_IntegerConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_IntegerConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_IntegerConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_IntegerConstantValueTag$refs {
    _jc_soot_tagkit_IntegerConstantValueTag$sub_refs	soot_tagkit_IntegerConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_IntegerConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_IntegerConstantValueTag$sub_nonrefs	soot_tagkit_IntegerConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_IntegerConstantValueTag$object {
	_jc_soot_tagkit_IntegerConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_IntegerConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_IntegerConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_IntegerConstantValueTag$vtype _jc_soot_tagkit_IntegerConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_IntegerConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_IntegerConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_IntegerConstantValueTag_H_ */
